@@ -591,7 +591,20 @@ int main (int argc, char *argv[]) {
 		fclose(file);
 	}
 	if(!ignore_locale) {
-#	ifdef WIN32
+#	ifdef _WIN32
+		if(lang.empty()) {
+			ULONG nlang = 0;
+			DWORD n = 0;
+			if(GetUserPreferredUILanguages(MUI_LANGUAGE_NAME, &nlang, NULL, &n)) {
+				WCHAR wlocale[n];
+				if(GetUserPreferredUILanguages(MUI_LANGUAGE_NAME, &nlang, wlocale, &n)) {
+					lang = utf8_encode(wlocale);
+					gsub("-", "_", lang);
+					if(lang.length() > 5) lang = lang.substr(0, 5);
+					if(!lang.empty()) _putenv_s("LANG", lang.c_str());
+				}
+			}
+		}
 		bindtextdomain(GETTEXT_PACKAGE, getPackageLocaleDir().c_str());
 #	else
 		bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
